| igfetchr-package | R Documentation |
igfetchr provides a small set of beginner-friendly functions to authenticate with and fetch market data, historical prices, account details, options positions, and execute trades from the IG Trading REST API (https://labs.ig.com/). All functions return tidy tibbles for straightforward analysis.
Disclaimer: Trading CFDs, spread bets, and options carries a high risk of losing money. This package provides data access and trade execution functionality only and is not financial or trading advice.
Maintainer: Saw Simeon saw.s@ku.th
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.